@@ -1,6 +1,6 @@
 package App::JobLog::Command::info;
 {
-  $App::JobLog::Command::info::VERSION = '1.026';
+  $App::JobLog::Command::info::VERSION = '1.027';
 }
 
 # ABSTRACT: provides general App::JobLog information
@@ -146,17 +146,30 @@ sub _basic_usage {
     
 ==head1 Usage
 
-B<Job Log> keeps a log of events. If you begin a new task you type
+B<Job Log> keeps a log of events and notes. If you begin a new task you type
 
    $executable @{[App::JobLog::Command::add->name]} what I am doing now
 
 and it appends the following, modulo changes in time, to @{[log]}:
 
    2011 2 1 15 19 12::what I am doing now
-
+   
 The portion before the first colon is a timestamp in year month day hour minute second format.
-The portion after the second colon is your description of the event. The portion between the
-colons, here blank, is a list of space-delimited tags one can use to categorize events. For
+The portion after the second colon is your description of the event. 
+
+If you wish to take a note, you type
+
+   $executable @{[App::JobLog::Command::note->name]} something I should remember
+
+and it appends the following to @{[log]}:
+
+   2011 2 1 15 19 12<NOTE>:something I should remember
+   
+Again, the portion before the first colon is a timestamp. The portion after the E<lt>NOTEE<gt> is 
+the body of the note.
+
+The text between the two colons, or between the first colon and the E<lt>NOTEE<gt> tag, which is blank in these
+examples, is a list of space-delimited tags one can use to categorize things. For
 instance, if you were performing this task for Acme Widgets you might have typed
 
    $executable @{[App::JobLog::Command::add->name]} -t "Acme Widgets" what I am doing now
@@ -179,7 +192,7 @@ producing
 For readability it is probably best to avoid spaces in tags.
 
 Since one usually works on a particular project for an extended period of time, if you specify no tags
-the event is given the same tags as the preceding event. For example,
+the event or note is given the same tags as the preceding event/note. For example,
 
    $executable @{[App::JobLog::Command::add->name]} -t foo what I am doing now
    $executable @{[App::JobLog::Command::add->name]} now something else
@@ -197,8 +210,8 @@ which adds something like
 
    2011 2 1 16 19 12:DONE
 
-to the log. Note the single colon. In this case I<DONE> is not a tag, though it is made
-to appear similar since it serves a similar function.
+to the log. Note the single colon. In this case I<DONE> is not a tag. Tags are always sandwiched between
+two delimiters. I<DONE> here just marks the line as the end of a task.
 
 When you come back to work you can type
 
@@ -399,7 +412,7 @@ sub _bnf {
   <modifiable_day_no_time> = [ <modifier> s ] <weekday>
         <modifiable_month> = [ <month_modifier> s ] <month>
        <modifiable_period> = [ <period_modifier> s ] <period>
-                <modifier> = "last" | "this" 
+                <modifier> = "last" | "this" | "next"
                    <month> = <full_month> | <short_month> 
                <month_day> = <at_time_on> <month_day_no_time> | <month_day_no_time> <at_time>
        <month_day_no_time> = <month_first> | <day_first>
@@ -414,7 +427,7 @@ sub _bnf {
                   <period> = "week" | "month" | "year" | <pay>
          <period_modifier> = <modifier> | <termini> [ s "of" [ s "the" ] ] 
          <relative_period> = [ <at> s* ] <time> s <relative_period_no_time> | <relative_period_no_time> <at_time> | <now>
- <relative_period_no_time> = "yesterday" | "today"
+ <relative_period_no_time> = "yesterday" | "today" | "tomorrow"
              <short_month> = "jan" | "feb" | "mar" | "apr" | "may" | "jun" | "jul" | "aug" | "sep" | "oct" | "nov" | "dec"
            <short_weekday> = "sun" | "mon" | "tue" | "wed" | "thu" | "fri" | "sat" 
             <span_divider> = s* ( "-"+ | ( "through" | "thru" | "to" | "til" [ "l" ] | "until" ) ) s*
@@ -441,7 +454,7 @@ App::JobLog::Command::info - provides general App::JobLog information
 
 =head1 VERSION
 
-version 1.026
+version 1.027
 
 =head1 SYNOPSIS
 
